﻿/******************************************************************************
 * The MIT License (MIT)
 * 
 * Copyright (c) 2016 Bunny83
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/
namespace B83.VisPortalSystem
{

    using UnityEngine;
    using System.Collections;
    using System.Collections.Generic;

    /// <summary>
    /// This class defines a group of objects which belong to a certain area. 
    /// Currently each Area has a PolyArea to define the boundary of the area.
    /// This boundary is used to determine if a point is inside the area. The
    /// "portals" array should contain all portals that belong to this area. So
    /// only those portals that allows you to leave this area
    /// 
    /// "isVisible" is set / reset during the visibility check by the VisAreaManager
    /// 
    /// "UpdateState" finally applies the visibility state to this area by activating /
    /// deactivating the whole gameobject.
    ///
    /// </summary>
    public class VisArea : MonoBehaviour
    {
        public PolyArea area;
        public List<VisPortal> portals;
        public bool isVisible = false;
        public void UpdateState()
        {
            if (gameObject.activeSelf != isVisible)
                gameObject.SetActive(isVisible);
        }
    }
}